@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: Crypto
-version: 4.2.5
-id: Crypto-4.2.5-99f49e9cc5efc5d1ea1975c7a351c2ad
+version: 4.2.5.1
+id: Crypto-4.2.5.1-d45919786e6a539597df483a572131b3
 
 license: OtherLicense
 copyright: Dominic Steinitz 2003 - 2007
@@ -29,24 +29,24 @@ exposed-modules: Codec.Binary.BubbleBabble Codec.Encryption.RSA
 hidden-modules: Codec.Encryption.BlowfishAux
                 Codec.Encryption.DESAux Codec.Encryption.AESAux Data.Digest.MD5Aux
 trusted: False
-import-dirs: /usr/local/lib/ghc/Crypto-4.2.5
-library-dirs: /usr/local/lib/ghc/Crypto-4.2.5
-hs-libraries: HSCrypto-4.2.5
+import-dirs: /usr/local/lib/ghc/Crypto-4.2.5.1
+library-dirs: /usr/local/lib/ghc/Crypto-4.2.5.1
+hs-libraries: HSCrypto-4.2.5.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: HUnit-1.2.5.1-3a320959e06d702551395cbe60e9b4d5
-         QuickCheck-2.5.1.1-4a9242f1b61a140fe486a54f5467ba42
-         array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
-         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         pretty-1.1.1.0-91ed62f0481a81d292d550eec35ee75b
-         random-1.0.1.1-d8f82f84701874725b418c29860a58e0
+depends: HUnit-1.2.5.2-037d72e94f82e21ad0efc3a3ca13d5e2
+         QuickCheck-2.6-7e3d016625f4d442b87676aa1ce93592
+         array-0.4.0.1-6380782b62ead58fec616aa07dc0e15c
+         base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         pretty-1.1.1.0-2de27f83b2c1c65d629a564e9e01b27d
+         random-1.0.1.1-de2c78bd5b6a198d2ecb982e7d11c02f
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-Crypto-4.2.5/html/Crypto.haddock
-haddock-html: /usr/local/share/doc/hs-Crypto-4.2.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-Crypto-4.2.5.1/html/Crypto.haddock
+haddock-html: /usr/local/share/doc/hs-Crypto-4.2.5.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
